Name:           rapidsvn
Version:        0.10.0
Release:        1%{?dist}
Summary:        Graphical interface for the Subversion revision control system

Group:          Development/Tools
License:        GPLv3+
URL:            http://www.rapidsvn.org/
Source0:        http://rapidsvn.org/download/release/%{version}/rapidsvn-%{version}.tar.gz

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# Has to be a manual requirement, because the library version appears to not
# be being bumped upstream on API changes - well, at least RapidSVN 0.9.2
# has unresolved symbols if run against svncpp from the 0.9.1 distribution
Requires:       svncpp = %{version}

BuildRequires:  apr-devel, apr-util-devel
BuildRequires:  libtool >= 1.4.2
BuildRequires:  openldap-devel

# For doc generation; rapidsvn needs the "dot" tool from graphviz
BuildRequires:  docbook-style-xsl >= 1.58.1, doxygen, libxslt >= 1.0.27
BuildRequires:  graphviz

BuildRequires:  wxGTK-devel >= 2.4.2
BuildRequires:  desktop-file-utils

%description
RapidSVN is a GUI front-end for the Subversion revision control system. It
allows access to most of the features of Subversion through a user-friendly
interface.

%package -n svncpp
Summary:        C++ bindings for the Subversion client library
Group:          Development/Libraries
License:        GPLv3+
BuildRequires:  subversion-devel
# for test framework
BuildRequires:  cppunit-devel
Requires:       subversion
Requires(pre):  /sbin/ldconfig
Requires(post): /sbin/ldconfig

%description -n svncpp
svncpp is a C++ wrapper for the C Subversion client library which abstracts
many parts of the C API and provides an object-oriented programming interface.

%package -n svncpp-devel
Summary:        Development resources for the 'svncpp' library
Group:          Development/Libraries
License:        GPLv3+
Requires:       svncpp = %{version}-%{release}

%description -n svncpp-devel
Development resources for the 'svncpp' C++ client library for Subversion.
Install this package if you need to compile an application that requires the
'svncpp' library.

%prep
%setup -q

# Fix broken configure
sed -i s_src/tests/svncpp/Makefile__ configure

%{__cat} <<EOF >rapidsvn.desktop
[Desktop Entry]
Encoding=UTF-8
Name=RapidSVN
GenericName=Subversion client
Comment=Manage Subversion repositories
Exec=rapidsvn
Icon=rapidsvn
Terminal=false
Type=Application
Categories=Development;GNOME;GTK;RevisionControl;
Version=0.9.4
EOF

%build
# rapidsvn doesn't use neon directly, so trick the configure
# script into not linking against it using /bin/true in place
# of neon-config

%configure \
        --disable-static \
        --disable-no-exceptions \
        --with-svn-lib=%{_libdir} \
        --with-apu-config=%{_bindir}/apu-1-config \
        --with-apr-config=%{_bindir}/apr-1-config \
        --with-docbook-xsl-manpages=%{_datadir}/sgml/docbook/xsl-stylesheets/manpages/docbook.xsl \
        --with-neon-config=/bin/true

make %{?_smp_mflags} LIBTOOL=/usr/bin/libtool

pushd doc/manpage
make manpage
iconv --from-code ISO-8859-1 --to-code UTF-8 --output rapidsvn.1.utf8 rapidsvn.1
mv rapidsvn.1.utf8 rapidsvn.1
popd

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot} LIBTOOL=/usr/bin/libtool

# Install desktop file and icon
%{__install} -D -m 644 src/res/bitmaps/rapidsvn_48x48.xpm %{buildroot}%{_datadir}/pixmaps/rapidsvn.xpm
%{__install} -d -m 755 %{buildroot}%{_datadir}/applications/
desktop-file-install --vendor fedora               \
        --dir %{buildroot}%{_datadir}/applications \
        rapidsvn.desktop

# Install manpage
%{__install} -D -m 644 doc/manpage/rapidsvn.1 %{buildroot}%{_mandir}/man1/rapidsvn.1

# Remove libtool stuff
rm -f %{buildroot}%{_libdir}/libsvncpp.{a,la}

%clean
rm -rf %{buildroot}

%post -n svncpp -p /sbin/ldconfig
%postun -n svncpp -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS CHANGES FDL.txt GPL.txt LICENSE.txt README
%{_bindir}/rapidsvn
%{_datadir}/applications/fedora-rapidsvn.desktop
%{_datadir}/pixmaps/rapidsvn.xpm
%{_mandir}/man1/*

%files -n svncpp
%defattr(-,root,root,-)
%{_libdir}/libsvncpp.so.*

%files -n svncpp-devel
%defattr(-,root,root,-)
%doc doc/svncpp/html
%{_includedir}/svncpp/
%{_libdir}/libsvncpp.so

%changelog
* Sat Sep 05 2009 Tim Jackson <rpm@timj.co.uk> 0.10.0-1
- Update to v0.10.0
- Set default attrs for subpackages
- Rebuild fixes #520800

* Tue Apr 14 2009 Tim Jackson <rpm@timj.co.uk> 0.9.8-1
- Update to v0.9.8
- License is now GPLv3+
- Update .desktop file categories (#487867)

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Jul 07 2008 Tim Jackson <rpm@timj.co.uk> 0.9.6-3
- Add missing BR on openldap-devel

* Tue Jun 03 2008 Tim Jackson <rpm@timj.co.uk> 0.9.6-2
- Fix spec file to build using latest RPM version
- Remove filename suffix from icon in desktop file as per standards

* Tue Mar 11 2008 Tim Jackson <rpm@timj.co.uk> 0.9.6-1
- Update to upstream 0.9.6 (#436157)
- Fix build on gcc 4.3 (#434474)
- Update License tags

* Mon Sep  3 2007 Joe Orton <jorton@redhat.com> 0.9.4-6
- rebuild for fixed 32-bit APR

* Thu Aug 23 2007 Joe Orton <jorton@redhat.com> 0.9.4-5
- don't link against neon directly

* Sat Dec 30 2006 Tim Jackson <rpm@timj.co.uk> 0.9.4-3
- Apply patches to build against wxGTK 2.8

* Sat Dec 30 2006 Tim Jackson <rpm@timj.co.uk> 0.9.4-3
- Rebuild for new wxGTK

* Sat Dec 09 2006 Tim Jackson <rpm@timj.co.uk> 0.9.4-2
- Nasty dist tag conflict (fc6 in devel)

* Sat Dec 09 2006 Tim Jackson <rpm@timj.co.uk> 0.9.4-1
- Update to 0.9.4
- Use new RapidSVN desktop icon

* Sat Sep 09 2006 Tim Jackson <rpm@timj.co.uk> 0.9.3-2
- Rebuild for FE6

* Fri Jun 23 2006 Tim Jackson <rpm@timj.co.uk> 0.9.3-1
- Update to 0.9.3
- Remove gcc4 patch; now fixed upstream

* Tue May 30 2006 Tim Jackson <rpm@timj.co.uk> 0.9.2-1
- Update to 0.9.2
- Add explicit dep on svn-cpp = [rapidsvn ver]

* Wed May 03 2006 Tim Jackson <rpm@timj.co.uk> 0.9.1-3
- libtool hack to fix RPATH issue

* Sat Apr 29 2006 Tim Jackson <rpm@timj.co.uk> 0.9.1-2
- Update list of docs inc. add GPL, LGPL docs and LICENSE.txt
- Remove autoconf from BR
- Fix manpage generation and add manpage to package
- Add graphviz BR for correct doc generation
- Add --disable-no-exceptions per README
- Use --disable-static since we don't use the static libs
- Spin off svncpp and svncpp-devel subpackages
- svncpp has ldconfig in post/postun
- Add --with-svn-lib which should fix build on x86_64
- Add %%check section using package's inbuilt tests (requires cppunit)

* Thu Apr 27 2006 Tim Jackson <rpm@timj.co.uk> 0.9.1-1
- Initial package for Fedora Extras; based originally on an old DAG spec
